@@ -7,9 +7,9 @@ from time import time
 from astropy.wcs import WCS
 from decimal import Decimal
 from uncertainty import z_uncert
-from fits2flux import fits2flux, wcs2pix, pix2wcs
-from flux_zfind import flux_zfind, gaussf, find_lines
-from fft_zfind import fft_zfind, fft, double_damped_sinusoid
+from zfinder.fits2flux import fits2flux, wcs2pix, pix2wcs
+from zfinder.flux_zfind import flux_zfind, gaussf, find_lines
+from zfinder.fft_zfind import fft_zfind, fft, double_damped_sinusoid
 
 # Get the prefix of a unit from an exponent
 prefix = {-24 : 'y', -21 : 'z', -18 : 'a',
